@@ -24,7 +24,8 @@ class ArangoClient(object):
     :param username: ArangoDB username (default: ``"root"``)
     :type username: str | unicode
     :param password: ArangoDB password (default: ``""``)
-    :param verify: check the connection during initialization
+    :param verify: check the connection during initialization. Root privileges
+        are required to use this check.
     :type verify: bool
     :param http_client: the HTTP client object
     :type http_client: arango.http_clients.base.BaseHTTPClient
@@ -83,6 +84,11 @@ class ArangoClient(object):
         :rtype: bool
         :raises arango.exceptions.ServerConnectionError: if the connection to
             the ArangoDB server fails
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.verify` (via a database
+            the users have access to) instead.
         """
         res = self._conn.head('/_api/version')
         if res.status_code not in HTTP_OK:
@@ -168,6 +174,11 @@ class ArangoClient(object):
         :rtype: str | unicode
         :raises arango.exceptions.ServerVersionError: if the server version
             cannot be retrieved
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.version` (via a database
+            the users have access to) instead.
         """
         res = self._conn.get(
             endpoint='/_api/version',
@@ -184,6 +195,11 @@ class ArangoClient(object):
         :rtype: dict
         :raises arango.exceptions.ServerDetailsError: if the server details
             cannot be retrieved
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.details` (via a database
+            the users have access to) instead.
         """
         res = self._conn.get(
             endpoint='/_api/version',
@@ -200,6 +216,11 @@ class ArangoClient(object):
         :rtype: str | unicode
         :raises arango.exceptions.ServerRequiredDBVersionError: if the
             required database version cannot be retrieved
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.required_db_version` (via
+            a database the users have access to) instead.
         """
         res = self._conn.get('/_admin/database/target-version')
         if res.status_code not in HTTP_OK:
@@ -213,6 +234,11 @@ class ArangoClient(object):
         :rtype: dict
         :raises arango.exceptions.ServerStatisticsError: if the server
             statistics cannot be retrieved
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.statistics` (via a database
+            the users have access to) instead.
         """
         res = self._conn.get(
             '/_admin/statistics-description'
@@ -236,6 +262,11 @@ class ArangoClient(object):
         :rtype: str | unicode
         :raises arango.exceptions.ServerRoleError: if the server role cannot
             be retrieved
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.role` (via a database the
+            users have access to) instead.
         """
         res = self._conn.get('/_admin/server/role')
         if res.status_code not in HTTP_OK:
@@ -249,6 +280,11 @@ class ArangoClient(object):
         :rtype: datetime.datetime
         :raises arango.exceptions.ServerTimeError: if the server time
             cannot be retrieved
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.time` (via a database the
+            users have access to) instead.
         """
         res = self._conn.get('/_admin/time')
         if res.status_code not in HTTP_OK:
@@ -267,6 +303,9 @@ class ArangoClient(object):
         :rtype: list
         :raises arango.exceptions.ServerEndpointsError: if the endpoints
             cannot be retrieved from the server
+
+        .. note::
+            Only the root user can access this method.
         """
         res = self._conn.get('/_api/endpoint')
         if res.status_code not in HTTP_OK:
@@ -280,6 +319,11 @@ class ArangoClient(object):
         :rtype: dict
         :raises arango.exceptions.ServerEchoError: if the last request cannot
             be retrieved from the server
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.echo` (via a database the
+            users have access to) instead.
         """
         res = self._conn.get('/_admin/echo')
         if res.status_code not in HTTP_OK:
@@ -295,6 +339,11 @@ class ArangoClient(object):
         :rtype: int
         :raises arango.exceptions.ServerSleepError: if the server cannot be
             suspended
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.sleep` (via a database the
+            users have access to) instead.
         """
         res = self._conn.get(
             '/_admin/sleep',
@@ -311,6 +360,11 @@ class ArangoClient(object):
         :rtype: bool
         :raises arango.exceptions.ServerShutdownError: if the server shutdown
             sequence cannot be initiated
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.shutdown` (via a database
+            the users have access to) instead.
         """
         try:
             res = self._conn.delete('/_admin/shutdown')
@@ -328,6 +382,11 @@ class ArangoClient(object):
         :returns: the test results
         :rtype: dict
         :raises arango.exceptions.ServerRunTestsError: if the test suites fail
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.run_tests` (via a database
+            the users have access to) instead.
         """
         res = self._conn.post('/_admin/test', data={'tests': tests})
         if res.status_code not in HTTP_OK:
@@ -343,6 +402,11 @@ class ArangoClient(object):
         :rtype: str | unicode
         :raises arango.exceptions.ServerExecuteError: if the program cannot
             be executed on the server
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.execute` (via a database
+            the users have access to) instead.
         """
         res = self._conn.post('/_admin/execute', data=program)
         if res.status_code not in HTTP_OK:
@@ -385,6 +449,11 @@ class ArangoClient(object):
         :rtype: dict
         :raises arango.exceptions.ServerReadLogError: if the server log entries
             cannot be read
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.read_log` (via a database
+            the users have access to) instead.
         """
         params = dict()
         if upto is not None:
@@ -416,6 +485,11 @@ class ArangoClient(object):
 
         :return: the current logging levels
         :rtype: dict
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.log_levels` (via a database
+            the users have access to) instead.
         """
         res = self._conn.get('/_admin/log/level')
         if res.status_code not in HTTP_OK:
@@ -436,14 +510,19 @@ class ArangoClient(object):
                 threads='WARNING'
             )
 
+        :return: the new logging levels
+        :rtype: dict
+
         .. note::
             Keys that are not valid logger names are simply ignored.
 
         .. note::
             This method is only compatible with ArangoDB version 3.1+ only.
 
-        :return: the new logging levels
-        :rtype: dict
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.set_log_levels` (via a
+            database the users have access to) instead.
         """
         res = self._conn.put('/_admin/log/level', data=kwargs)
         if res.status_code not in HTTP_OK:
@@ -457,6 +536,11 @@ class ArangoClient(object):
         :rtype: bool
         :raises arango.exceptions.ServerReloadRoutingError: if the routing
             cannot be reloaded
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.reload_routing` (via a
+            database the users have access to) instead.
         """
         res = self._conn.post('/_admin/routing/reload')
         if res.status_code not in HTTP_OK:
@@ -468,13 +552,16 @@ class ArangoClient(object):
     #######################
 
     def databases(self, user_only=False):
-        """"Return the database names.
+        """Return the database names.
 
         :param user_only: list only the databases accessible by the user
         :type user_only: bool
         :returns: the database names
         :rtype: list
         :raises arango.exceptions.DatabaseListError: if the retrieval fails
+
+        .. note::
+            Only the root user can access this method.
         """
         # Get the current user's databases
         res = self._conn.get(
@@ -488,7 +575,7 @@ class ArangoClient(object):
     def db(self, name, username=None, password=None):
         """Return the database object.
 
-        This is an alias for :func:`~arango.client.ArangoClient.database`.
+        This is an alias for :func:`arango.client.ArangoClient.database`.
 
         :param name: the name of the database
         :type name: str | unicode
@@ -561,6 +648,10 @@ class ArangoClient(object):
 
             If **users** is not set, only the root and the current user are
             granted access to the new database by default.
+
+        .. note::
+            Root privileges (i.e. access to the ``_system`` database) are
+            required to use this method.
         """
         res = self._conn.post(
             '/_api/database',
@@ -588,6 +679,10 @@ class ArangoClient(object):
         :returns: whether the database was deleted successfully
         :rtype: bool
         :raises arango.exceptions.DatabaseDeleteError: if the delete fails
+
+        .. note::
+            Root privileges (i.e. access to the ``_system`` database) are
+            required to use this method.
         """
         res = self._conn.delete('/_api/database/{}'.format(name))
         if res.status_code not in HTTP_OK:
@@ -607,8 +702,9 @@ class ArangoClient(object):
         :raises arango.exceptions.UserListError: if the retrieval fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.users` (via a database the
+            users have access to) instead.
         """
         res = self._conn.get('/_api/user')
         if res.status_code not in HTTP_OK:
@@ -629,8 +725,9 @@ class ArangoClient(object):
         :raises arango.exceptions.UserGetError: if the retrieval fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.user` (via a database the
+            users have access to) instead.
         """
         res = self._conn.get('/_api/user/{}'.format(username))
         if res.status_code not in HTTP_OK:
@@ -657,8 +754,9 @@ class ArangoClient(object):
         :raises arango.exceptions.UserCreateError: if the user create fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.create_user` (via a database
+            the users have access to) instead.
         """
         data = {'user': username, 'passwd': password}
         if active is not None:
@@ -691,8 +789,9 @@ class ArangoClient(object):
         :raises arango.exceptions.UserUpdateError: if the user update fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.update_user` (via a database
+            the users have access to) instead.
         """
         data = {}
         if password is not None:
@@ -730,8 +829,9 @@ class ArangoClient(object):
         :raises arango.exceptions.UserReplaceError: if the user replace fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.replace_user` (via a database
+            the users have access to) instead.
         """
         data = {'user': username, 'passwd': password}
         if active is not None:
@@ -764,8 +864,9 @@ class ArangoClient(object):
         :raises arango.exceptions.UserDeleteError: if the user delete fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.delete_user` (via a database
+            the users have access to) instead.
         """
         res = self._conn.delete('/_api/user/{user}'.format(user=username))
         if res.status_code in HTTP_OK:
@@ -784,8 +885,9 @@ class ArangoClient(object):
         :raises: arango.exceptions.UserAccessError: if the retrieval fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.user_access` (via a database
+            the users have access to) instead.
         """
         res = self._conn.get('/_api/user/{}/database'.format(username))
         if res.status_code in HTTP_OK:
@@ -804,8 +906,9 @@ class ArangoClient(object):
         :raises arango.exceptions.UserGrantAccessError: if the operation fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.grant_user_access` (via a
+            database the users have access to) instead.
         """
         res = self._conn.put(
             '/_api/user/{}/database/{}'.format(username, database),
@@ -827,8 +930,9 @@ class ArangoClient(object):
         :raises arango.exceptions.UserRevokeAccessError: if the operation fails
 
         .. note::
-            Root privileges (i.e. access to the ``_system`` database) are
-            required to use this method.
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.revoke_user_access` (via a
+            database the users have access to) instead.
         """
         res = self._conn.put(
             '/_api/user/{}/database/{}'.format(username, database),
@@ -852,6 +956,11 @@ class ArangoClient(object):
         :returns: the list of job IDs
         :rtype: [str]
         :raises arango.exceptions.AsyncJobListError: if the retrieval fails
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.async_jobs` (via a database
+            the users have access to) instead.
         """
         res = self._conn.get(
             '/_api/job/{}'.format(status),
@@ -874,6 +983,11 @@ class ArangoClient(object):
 
         .. note::
             Async jobs currently queued or running are not stopped.
+
+        .. note::
+            Only the root user can access this method. For non-root users,
+            use :func:`arango.database.Database.clear_async_jobs` (via a
+            database the users have access to) instead.
         """
         if threshold is None:
             res = self._conn.delete('/_api/job/all')
